@@ -14,15 +14,28 @@ namespace Tomboy.Sync
 		// that supports a field, a username, and password.  This could be useful
 		// in quickly building SshSyncServiceAddin, FtpSyncServiceAddin, etc.
 		
-		Entry pathEntry;
-		string path;
+		private Entry pathEntry;
+		private string path;
+		private bool initialized = false;
 		
 		/// <summary>
 		/// Called as soon as Tomboy needs to do anything with the service
 		/// </summary>
 		public override void Initialize ()
 		{
+			initialized = true;
 		}
+		
+		public override void Shutdown ()
+		{
+			// Do nothing for now
+		}
+		
+		public override bool Initialized {
+			get { return initialized; }
+		}
+
+
 
 		/// <summary>
 		/// Creates a SyncServer instance that the SyncManager can use to
@@ -66,31 +79,56 @@ namespace Tomboy.Sync
 		/// </summary>
 		public override Gtk.Widget CreatePreferencesControl ()
 		{
-			Gtk.Table table = new Gtk.Table (1, 2, false);
+			Gtk.Table table = new Gtk.Table (1, 3, false);
 			
 			// Read settings out of gconf
 			string syncPath;
 			if (GetConfigSettings (out syncPath) == false)
 				syncPath = string.Empty;
-			
-			bool activeSyncService = syncPath != string.Empty;
-			
-			// TODO: Use a FileChooserDialog to allow the user to choose a path more easily
-			Label l = new Label (Catalog.GetString ("Path:"));
+
+			Label l = new Label (Catalog.GetString ("Folder Path:"));
 			l.Xalign = 1;
-			l.Show ();
 			table.Attach (l, 0, 1, 0, 1);
 			
 			pathEntry = new Entry ();
 			pathEntry.Text = syncPath;
-			pathEntry.Show ();
 			table.Attach (pathEntry, 1, 2, 0, 1);
 			
-			table.Sensitive = !activeSyncService;
-			table.Show ();
+			Image browseImage = new Image (Stock.Open, IconSize.Button);
+			Label browseLabel = new Label (Catalog.GetString ("Browse..."));
+			
+			HBox browseBox = new HBox (false, 0);
+			browseBox.PackStart (browseImage);
+			browseBox.PackStart (browseLabel);			
+			
+			Button browseButton = new Button ();
+			browseButton.Add (browseBox);
+			browseButton.Clicked += OnBrowseButtonClicked;
+			table.Attach (browseButton, 2, 3, 0, 1, AttachOptions.Shrink, AttachOptions.Expand, 0, 0);
+			
+			table.ShowAll ();
 			return table;
 		}
 		
+		private void OnBrowseButtonClicked (object sender, EventArgs args)
+		{
+			FileChooserDialog chooserDlg =
+				new FileChooserDialog (Catalog.GetString ("Select Synchronization Folder..."),
+				                       null,
+				                       FileChooserAction.SelectFolder,
+				                       Stock.Cancel, ResponseType.Cancel,
+				                       Stock.Ok, ResponseType.Ok);
+			chooserDlg.DefaultResponse = ResponseType.Cancel;
+			chooserDlg.SetFilename (pathEntry.Text);
+			
+			ResponseType response = (ResponseType) chooserDlg.Run ();
+			
+			if (response == ResponseType.Ok)
+				pathEntry.Text = chooserDlg.Filename;
+			
+			chooserDlg.Destroy ();
+		}
+		
 		/// <summary>
 		/// The Addin should verify and check the connection to the service
 		/// when this is called.  If verification and connection is successful,
@@ -155,7 +193,7 @@ namespace Tomboy.Sync
 		public override string Name
 		{
 			get {
-				return Mono.Unix.Catalog.GetString ("Local File System Path");
+				return Mono.Unix.Catalog.GetString ("Local Folder");
 			}
 		}
 
@@ -184,20 +222,6 @@ namespace Tomboy.Sync
 		}
 		
 		#region Private Methods
-		private void CreateSyncPath ()
-		{
-			if (Directory.Exists (path) == false) {
-				try {
-					Directory.CreateDirectory (path);
-				} catch (Exception e) {
-					throw new Exception (
-						string.Format (
-							"Couldn't create \"{0}\" directory: {1}",
-							path, e.Message));
-				}
-			}
-		}
-		
 		/// <summary>
 		/// Get config settings
 		/// </summary>
